web

package
v0.0.0-...-8da6f21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2023 License: GPL-3.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ProductRoutes

func ProductRoutes(srv Server) *chi.Mux

Types

type Server

type Server interface {
	Mux() *chi.Mux
	Storage() storage.Storage
	Logger() config.Logger
	RateLimit() int
	MountHandlers()
}

Server is an interface that defines the methods required for a server.

func NewServer

func NewServer(mode string, config config.Config) Server

NewServer is a factory function that returns a Server interface based on the mode passed in. The Server is initialized with the config passed in.

Jump to